--[[
    Baldrick_Classic_Horde by LordFarlander
    Version 1.5.5
    $Revision: 5 $
]]--

--[[
Copyright (c) 2008, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local Baldrick = _G["Baldrick"];

if( not Baldrick ) then
    error( L["%s requires %s"]:format( "Baldrick_Classic_Horde", "Baldrick" ) );
    return;
end--if

local L = LibStub( "AceLocale-3.0" ):GetLocale( "Baldrick_Classic" );
local LBZ = LibStub( "LibBabble-Zone-3.0" );

if( LBZ ) then
    LBZ = LBZ:GetUnstrictLookupTable();
end--if

local ZONES = {};
setmetatable( ZONES, {
    __index = function( self, key )
            local returnVal = LBZ and LBZ[key];

            if( not returnVal ) then
                returnVal = L[key];
            end--if
            return returnVal;
        end } );

local NPCS = L;
local QuestObjectiveComplete = Baldrick.QuestObjectiveComplete;

local function IsTargetAliveAndNotTapped()
    return ( not UnitIsDead( "playertarget" ) ) and
       ( UnitIsTappedByPlayer( "playertarget" ) or ( not UnitIsTapped( "playertarget" ) ) );
end--IsTargetAliveAndNotTapped()

local function IsTargetDead()
    return UnitIsDead( "playertarget" );
end--IsTargetDead()

local quests = {
    --Eastern Kingdoms
    --Badlands
    {
        --Badlands Reagent Run II
        questIDs = 2203,
        --Empty Thaumaturgy Vessel
        questItems = { default = { questItem = 7866, questItemCount = 1, }, },
        target = NPCS["Scorched Guardian"],
    },
    --Blackrock Mountain
    {
        --Bodley's Unfortunate Fate
        questIDs = 9032,
        --Extra-Dimensional Ghost Revealer
        questItems = { default = { questItem = 22115, questItemCount = 1, }, },
        subZones = ZONES["Blackrock Mountain"],
    },
    --Eastern Plaguelands
    {
        --In Search of Anthion
        questIDs = 8930,
        --Extra-Dimensional Ghost Revealer
        questItems = { default = { questItem = 22115, questItemCount = 1, }, },
        subZones = ZONES["Stratholme"],
    },
    {
        --Nathanos' Ruse
        questIDs = 6146,
        --Rotten Apple
        questItems = { default = { questItem = 15875, questItemCount = 1, }, },
        subZones = ZONES["Tyr's Hand"],
        additionalEvents = { "LibSpecialEvents-Aura-4.0:PlayerBuffGained", "LibSpecialEvents-Aura-4.0:PlayerBuffLost" },
        func =
            function()
                return not LibStub( "LibSpecialEvents-Aura-4.0" ):UnitHasBuff( "player", select( 1, GetSpellInfo( 19690 ) ) );
            end,
    },
    {
        --To Kill With Purpose
        questIDs = 6022,
        --Mortar and Pestle, Living Rot
        questItems = { default = { questItem = 15454, questItemCount = 1, }, { questItem = 15447, questItemCount = 7, } },
    },
    --Hillsbrad Foothills
    {
        --Helcular's Revenge
        questIDs = 553,
        --Rod of Helcular
        questItems = { default = { questItem = 23191, questItemCount = 1, }, },
        subZones = ZONES["Hillsbrad Foothills"],
    },
    --Alterac Valley
    {
        --Empty Stables
        questIDs = 7001,
        --Frostwolf Muzzle
        questItems = { default = { questItem = 17626, questItemCount = 1, }, },
        target = NPCS["Frostwolf"],
        func = IsTargetAliveAndNotTapped;
    },
    --Hallow's End
    {
        --Stinking Up Southshore
        questIDs = 1657,
        --Forsaken Stink Bomb Cluster
        questItems = { default = { questItem = 20387, questItemCount = 1, }, },
        subZones = ZONES["Southshore"],
    },
    --Stranglethorn Vale
    {
        --An Unusual Patron
        questIDs = 9457,
        --Gift of Naias
        questItems = { default = { questItem = 23680, questItemCount = 1, }, },
        subZones = ZONES["Altar of Naias"],
    },
    --Swamp of Sorrows
    {
        --Little Morsels
        questIDs = 9440,
        --Fel-Tainted Morsels
        questItems = { default = { questItem = 23659, questItemCount = 1, }, },
        subZones = ZONES["Fallow Sanctuary"],
    },
    --The Hinterlands
    {
        --Grim Message
        questIDs = 2932,
        --Nimboya's Laden Pike
        questItems = { default = { questItem = 9319, questItemCount = 1, }, },
        subZones = ZONES["Hiri'watha"] .. "|" .. ZONES["Zun'watha"],
    },
    {
        --The Final Message to the Wildhammer
        questIDs = 7843,
        --Final Message to the Wildhammer
        questItems = { default = { questItem = 19036, questItemCount = 1, }, },
        subZones = ZONES["Aerie Peak"],
    },
    {
        --Grim Message
        questIDs = 2932,
        --Nimboya's Pike, Witherbark Skull
        questItems = { default = { questItem = 15002, questItemCount = 1, }, { questItem = 9320, questItemCount = 20, }, },
    },
    --Tirisfal Glades
    {
        --A Plague Upon Thee
        questIDs = 5901,
        --Empty Termite Jar
        questItems = { default = { questItem = 15042, questItemCount = 1, }, },
        subZones = ZONES["Plaguewood"],
    },
    --Undercity
    {
        --Seeping Corruption
        questIDs = 3568,
        --Empty Vial Labeled #1
        questItems = { default = { questItem = 10687, questItemCount = 1, }, },
        subZones = ZONES["Azshara"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 10691 ) ) );
            end,
    },
    {
        --Seeping Corruption
        questIDs = 3568,
        --Empty Vial Labeled #2
        questItems = { default = { questItem = 10688, questItemCount = 1, }, },
        subZones = ZONES["Azshara"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 10692 ) ) );
            end,
    },
    {
        --Seeping Corruption
        questIDs = 3568,
        --Empty Vial Labeled #3
        questItems = { default = { questItem = 10689, questItemCount = 1, }, },
        subZones = ZONES["Azshara"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 10693 ) ) );
            end,
    },
    {
        --Seeping Corruption
        questIDs = 3568,
        --Empty Vial Labeled #4
        questItems = { default = { questItem = 10690, questItemCount = 1, }, },
        subZones = ZONES["Azshara"],
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 10694 ) ) );
            end,
    },
    --Western Plaguelands
    {
        --All Along the Watchtowers
        questIDs = 5098,
        --Beacon Torch
        questItems = { default = { questItem = 12815, questItemCount = 1, }, },
        subZones = ZONES["Andorhal"],
    },
    {
        --Defiling Uther's Tomb
        questIDs = 9444,
        --Corrupted Mark of the Lightbringer
        questItems = { default = { questItem = 23691, questItemCount = 1, }, },
        subZones = ZONES["Uther's Tomb"],
    },
    
    --Kalimdor
    --Ashenvale
    {
        --King of the Foulweald
        questIDs = 6621,
        --Karang's Banner
        questItems = { default = { questItem = 16972, questItemCount = 1, }, },
        subZones = ZONES["Ashenvale"],
    },
    {
        --The Lost Pages
        questIDs = 6621,
        --Shredder Operating Manual - Page 1, Shredder Operating Manual - Page 2, Shredder Operating Manual - Page 3, Shredder Operating Manual - Page 4
        questItems = { default = { questItem = 16645, questItemCount = 1, }, { questItem = 16646, questItemCount = 1, }, { questItem = 16647, questItemCount = 1, }, { questItem = 16648, questItemCount = 1, }, },
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 16642 ) ) );
            end,
    },
    {
        --The Lost Pages
        questIDs = 6621,
        --Shredder Operating Manual - Page 5, Shredder Operating Manual - Page 6, Shredder Operating Manual - Page 7, Shredder Operating Manual - Page 8
        questItems = { default = { questItem = 16649, questItemCount = 1, }, { questItem = 16650, questItemCount = 1, }, { questItem = 16651, questItemCount = 1, }, { questItem = 16652, questItemCount = 1, }, },
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 16643 ) ) );
            end,
    },
    {
        --The Lost Pages
        questIDs = 6621,
        --Shredder Operating Manual - Page 9, Shredder Operating Manual - Page 10, Shredder Operating Manual - Page 11, Shredder Operating Manual - Page 12
        questItems = { default = { questItem = 16653, questItemCount = 1, }, { questItem = 16654, questItemCount = 1, }, { questItem = 16655, questItemCount = 1, }, { questItem = 16656, questItemCount = 1, }, },
        func = function( _, questID )
                return not QuestObjectiveComplete( questid, select( 1, GetItemInfo( 16644 ) ) );
            end,
    },
    --Harvest Festival
    {
        --Honoring a Hero
        questIDs = 8150,
        --Grom's Tribute
        questItems = { default = { questItem = 19851, questItemCount = 1, }, },
        subZones = ZONES["Demon Fall Canyon"],
    },
    --Durotar
    {
        --Lazy Peons
        questIDs = 5441,
        --Foreman's Blackjack
        questItems = { default = { questItem = 16114, questItemCount = 1, }, },
        target = NPCS["Lazy Peon"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --The Demon Seed
        questIDs = 924,
        --Flawed Power Stone
        questItems = { default = { questItem = 4986, questItemCount = 1, }, },
        subZones = ZONES["Dreadmist Peak"],
    },
    --Brewfest
    {
        --Catch the Wild Wolpertinger!
        questIDs = 11431,
        --Wolpertinger Net
        questItems = { default = { questItem = 32907, questItemCount = 1, }, },
        target = NPCS["Wild Wolpertinger"],
        func = IsTargetAliveAndNotTapped,
    },
    {
        --Chug and Chuck!
        questIDs = 12191,
        --Complimentary Brewfest Sampler
        questItems = { default = { questItem = 33096, questItemCount = 1, }, },
    },
    --Dustwallow Marsh
    {
        --Emberstrife
        questIDs = 6570,
        --Amulet of Draconic Subversion
        questItems = { default = { questItem = 16787, questItemCount = 1, }, },
        subZones = ZONES["Wyrmbog"],
    },
    {
        --Raze Direhorn Post!
        questIDs = 11205,
        --Tabetha's Torch
        questItems = { default = { questItem = 33072, questItemCount = 1, }, },
        subZones = ZONES["Direhorn Post"],
    },
    --Felwood
    {
        --Corrupted Sabers
        questIDs = 4506,
        --Winna's Kitten Carrier
        questItems = { default = { questItem = 12565, questItemCount = 1, }, },
        subZones = ZONES["Ruins of Constellas"],
    },
    {
        --Well of Corruption
        questIDs = 4505,
        --Hardened Flasket
        questItems = { default = { questItem = 12566, questItemCount = 1, }, },
        subZones = ZONES["Ruins of Constellas"],
    },
    --Feralas
    {
        --Faerie Dragon Muisek
        questIDs = 3125,
        --Faerie Dragon Muisek Vessel
        questItems = { default = { questItem = 9620, questItemCount = 1, }, },
        target = NPCS["Sprite Darter"] .. "|" .. NPCS["Sprite Dragon"],
        func = IsTargetDead,
    },
    {
        --Hippogryph Muisek
        questIDs = 3124,
        --Hippogryph Muisek Vessel
        questItems = { default = { questItem = 9619, questItemCount = 1, }, },
        target = NPCS["Frayfeather"],
        func = IsTargetDead,
    },
    {
        --Mountain Giant Muisek
        questIDs = 3127,
        --Mountain Giant Muisek Vessel
        questItems = { default = { questItem = 9621, questItemCount = 1, }, },
        target = NPCS["Land Walker"] .. "|" .. NPCS["Cliff Giant"],
        func = IsTargetDead,
    },
    {
        --Testing the Vessel
        questIDs = 3123,
        --Wildkin Muisek Vessel
        questItems = { default = { questItem = 9618, questItemCount = 1, }, },
        target = NPCS["Owlbeast"],
        subZones = ZONES["The Hinterlands"],
        func = IsTargetDead,
    },
    {
        --Treant Giant Muisek
        questIDs = 3126,
        --Treant Giant Muisek Vessel
        questItems = { default = { questItem = 9606, questItemCount = 1, }, },
        target = NPCS["Wandering Forest Walker"],
        func = IsTargetDead,
    },
    --Mulgore
    {
        --Bloodhoof Village
        questIDs = 772,
        --Water of the Seers
        questItems = { default = { questItem = 4823, questItemCount = 1, }, },
        subZones = ZONES["Bloodhoof Village"],
    },
    {
        --Dwarven Digging
        questIDs = 746,
        --Prospector's Pick
        questItems = { default = { questItem = 4702, questItemCount = 1, }, },
    },
    --Silithus
    {
        --Field Duty
        questIDs = 8731,
        --Unsigned Field Duty Papers
        questItems = { default = { questItem = 21143, questItemCount = 1, }, },
    },
    --Stonetalon Mountains
    {
        --Earthen Arise
        questIDs = 6481,
        --Enchanted Resonite Crystal
        questItems = { default = { questItem = 16603, questItemCount = 1, }, },
        subZones = ZONES["Boulderslide Cavern"],
    },
    {
        --New Life
        questIDs = 6381,
        --Enchanted Gaea Seeds
        questItems = { default = { questItem = 16208, questItemCount = 1, }, },
        subZones = ZONES["Charred Vale"],
    },
    --Tanaris
    {
        --Fire Plume Forged
        questIDs = 5802,
        --Skeleton Key Mold, Thorium Bar
        questItems = { default = { questItem = 14644, questItemCount = 1, }, { questItem = 12359, questItemCount = 2, }, },
        subZones = ZONES["Fire Plume Ridge"],
    },
    --Thousand Needles
    {
        --A Dip in the Moonwell
        questIDs = 9433,
        --Robotron Control Unit
        questItems = { default = { questItem = 23675, questItemCount = 1, }, },
    },
    --Thunder Bluff
    {
        --Morrowgrain Research
        questIDs = 3786,
        --Evergreen Pouch, Un'Goro Soil, Packet of Tharlendris Seeds
        questItems = { default = { questItem = 11020, questItemCount = 1, }, { questItem = 11018, questItemCount = 2, }, { questItem = 11022, questItemCount = 1, }, },
    },
    --Brewfest
    {
        --Pink Elekks On Parade
        questIDs = 11120,
        --Elekk Dispersion Ray
        questItems = { default = { questItem = 32960, questItemCount = 1, }, },
        target = NPCS["Eversong Pink Elekk"] .. "|" .. NPCS["Mulgore Pink Elekk"] .. "|" .. NPCS["Tirisfal Pink Elekk"],
        func =
            function( _, questid )
                local target, _ = UnitName( "playertarget" );

                return IsTargetAliveAndNotTapped() and
                    ( ( ( target == NPCS["Eversong Pink Elekk"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Eversong Pink Elekk slain"] ) ) ) or
                    ( ( target == NPCS["Mulgore Pink Elekk"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Mulgore Pink Elekk slain"] ) ) ) or
                    ( ( target == NPCS["Tirisfal Pink Elekk"] ) and ( not QuestObjectiveComplete( questid, OBJECTIVES["Tirisfal Pink Elekk slain"] ) ) ) );
            end,
    },
};

Baldrick:RegisterQuestModule( L["Classic Horde Quests"], quests, function() return UnitFactionGroup( "player" ) == "Horde" end );
